# Modeling Guide

This section provides an in-depth explanation of how the ANDES framework is set up for symbolic modeling and numerical simulation. It aims to help developers understand the internal architecture and implement customized DAE models.

````{only} html
## Who This Is For

This section is for developers who want to:
- Understand how ANDES models work internally
- Implement new power system device models
- Extend ANDES capabilities with custom components

For users who want to:
- Run simulations: see the {doc}`../tutorials/index` section
- Inspect model equations: see the {doc}`../tutorials/14-inspecting-models` tutorial
````

```{toctree}
:maxdepth: 2

concepts/index
components/index
creating-models/index
```
